import { Switch, Route, useLocation, Redirect } from "wouter";
import { useEffect, useState, useCallback, createContext, lazy, Suspense } from "react";
import { useAuth } from "./contexts/AuthContext";
import { ProtectedRoute } from "./lib/protected-route";
import LaunchAnnouncement from "./components/ui/launch-announcement";
import CopyrightNotice from "./components/ui/copyright-notice";
import { useMobile } from "./providers/MobileProvider";
import { TooltipProvider } from "@/components/ui/tooltip";
import "./i18n"; // Import i18n configuration
import { queryClient } from "./lib/queryClient";
import { LanguageProvider } from './contexts/LanguageContext';
import MotionBackgroundV2 from "@/components/ui/motion-background-v2";
import { CountdownProvider } from "@/components/ui/launch-countdown";
import { SoundInitializer } from "@/components/system/SoundInitializer";
import { ToastInitializer } from "@/components/ToastInitializer";
// Performance optimization components
import StartupOptimizer from "@/components/system/StartupOptimizer";
import PreloadResources from "@/components/system/PreloadResources";
// Use correct import for IOSRedirect component
import { IOSRedirect } from "@/components/IOSRedirect";
// We'll use dynamic imports for iOS detection like in Auth.tsx
// Offline support
import { initOfflineSupport, updateLastOnlineTime } from "@/lib/offline-data-manager";
// Weather effects component
import WeatherEffects from "@/components/weather/WeatherEffects";

// Eager imports for critical components
import Login from "./pages/Login";
import Dashboard from "./pages/Dashboard";
import NotFound from "@/pages/not-found";
import MobileLoginPage from "@/pages/mobile-login-page";

// Mobile device detection import
import { isMobileDevice } from "@/lib/deviceDetector";

// Create context for UI overlay state
export type UIOverlayContextType = {
  isMenuOpen: boolean;
  setIsMenuOpen: (isOpen: boolean) => void;
  floatingButtonsVisible: boolean;
  setFloatingButtonsVisible: (visible: boolean) => void;
};

export const UIOverlayContext = createContext<UIOverlayContextType>({
  isMenuOpen: false,
  setIsMenuOpen: () => {},
  floatingButtonsVisible: true,
  setFloatingButtonsVisible: () => {},
});

// Lazy imports for all other components
const Auth = lazy(() => import("./pages/Auth"));
const SimpleAuth = lazy(() => import("./pages/SimpleAuth"));
const Referrals = lazy(() => import("./pages/Referrals"));
const ReferralMatrixPage = lazy(() => import("./pages/ReferralMatrixPage"));
const Games = lazy(() => import("./pages/Games"));
const Transactions = lazy(() => import("./pages/Transactions"));
const Subscription = lazy(() => import("./pages/Subscription"));
const SubscriptionComplete = lazy(() => import("./pages/SubscriptionComplete"));
const SubscriptionManagement = lazy(() => import("./pages/SubscriptionManagement"));
const SubscriptionCancel = lazy(() => import("./pages/SubscriptionCancel"));
const Subscribe = lazy(() => import("./pages/Subscribe"));
const FeaturesManagement = lazy(() => import("./pages/FeaturesManagement"));
const PaymentManagement = lazy(() => import("./pages/PaymentManagement"));
const FinancialTools = lazy(() => import("./pages/FinancialTools"));
const Profile = lazy(() => import("./pages/Profile"));
const Help = lazy(() => import("./pages/Help"));
const Surveys = lazy(() => import("./pages/Surveys"));
const Payment = lazy(() => import("./pages/Payment"));
const Guides = lazy(() => import("./pages/Guides"));
const Chat = lazy(() => import("./pages/Chat"));
const Admin = lazy(() => import("./pages/Admin"));
const Terms = lazy(() => import("./pages/Terms"));
const Privacy = lazy(() => import("./pages/Privacy"));
const Cookies = lazy(() => import("./pages/Cookies"));
const DailyChallenges = lazy(() => import("./pages/DailyChallenges"));
const Checkout = lazy(() => import("./pages/Checkout"));
const CheckoutSuccess = lazy(() => import("./pages/CheckoutSuccess"));
const PaymentSuccess = lazy(() => import("./pages/payment-success"));
const Multiplayer = lazy(() => import("./pages/Multiplayer"));
const NotificationTest = lazy(() => import("./pages/NotificationTest"));
const SecurityReport = lazy(() => import("./pages/SecurityReport"));
const UXEnhancements = lazy(() => import("./pages/UXEnhancements"));
const CryptoWallet = lazy(() => import("./pages/CryptoWallet"));
const AccessibilityHelp = lazy(() => import("./pages/AccessibilityHelp"));
const Accessibility = lazy(() => import("./pages/Accessibility"));
const AboutUs = lazy(() => import("./pages/AboutUs"));
const OurMission = lazy(() => import("./pages/OurMission"));
const Careers = lazy(() => import("./pages/Careers"));
const CareersApply = lazy(() => import("./pages/CareersApply"));
const Press = lazy(() => import("./pages/Press"));
const Blog = lazy(() => import("./pages/Blog"));
const Contact = lazy(() => import("./pages/Contact"));
const ApiDocs = lazy(() => import("./pages/ApiDocs"));
const Community = lazy(() => import("./pages/Community"));
const Partners = lazy(() => import("./pages/Partners"));
const Partnerships = lazy(() => import("./pages/Partnerships"));
const PartnerApplication = lazy(() => import("./pages/PartnerApplication"));
const LanguageSettings = lazy(() => import("./pages/LanguageSettings"));
const SupportTickets = lazy(() => import("./pages/SupportTickets"));
const CacheSettings = lazy(() => import("./pages/CacheSettings"));
const Security = lazy(() => import("./pages/Security"));
const SoundTestPage = lazy(() => import("./pages/SoundTestPage"));
const SoundTest = lazy(() => import("./pages/SoundTest"));
const LicenseVerification = lazy(() => import("./pages/LicenseVerification"));
const IPRights = lazy(() => import("./pages/IPRights"));
const TeamLicense = lazy(() => import("./pages/TeamLicense"));
const TeamSubscriptionPage = lazy(() => import("./pages/TeamSubscriptionPage"));
const Waitlist = lazy(() => import("./pages/Waitlist"));
const NetworkStatus = lazy(() => import("./pages/network-status"));

// UI components
const Header = lazy(() => import("@/components/layout/Header"));
const Sidebar = lazy(() => import("@/components/layout/Sidebar"));
const MobileNavigation = lazy(() => import("@/components/layout/MobileNavigation"));
const Footer = lazy(() => import("@/components/layout/Footer"));
const MainLayout = lazy(() => import("@/components/layout/MainLayout.jsx"));
const EnhancedMotionBackground = lazy(() => import("@/components/ui/enhanced-motion-background"));

// Import components with named exports
const SupportButtonModule = lazy(() => 
  import("@/components/ui/support-button")
    .then(module => ({ default: module.SupportButton }))
);

const QuickActionMenuModule = lazy(() => 
  import("@/components/ui/quick-action-menu")
    .then(module => ({ default: module.QuickActionMenu }))
);

const FloatingButtonsControllerModule = lazy(() => 
  import("@/components/ui/floating-buttons-controller")
    .then(module => ({ default: module.FloatingButtonsController }))
);

const PennyChatModalModule = lazy(() => 
  import("@/components/PennyChatModal")
    .then(module => ({ default: module.PennyChatModal }))
);

const AppErrorBoundary = lazy(() => import('./components/ErrorBoundary'));

// Import the common loader for consistency
import { FullPageLoader } from '@/components/ui/loader';

// Use FullPageLoader for all loading states to maintain consistent UX
const LoadingIndicator = () => <FullPageLoader label="Loading application..." />;

function App() {
  const [location] = useLocation();
  const [isMenuOpen, setIsMenuOpen] = useState(false);
  const [floatingButtonsVisible, setFloatingButtonsVisible] = useState(true);
  const [performanceOptimized, setPerformanceOptimized] = useState(false);
  
  // Get mobile context to handle device-specific behaviors
  const { isMobile, isIOS, isAndroid, isMobileReady } = useMobile();
  
  // ROBUST loading screen handling
  useEffect(() => {
    function hideScreenAggressively() {
      try {
        // Directly target element - do not rely on window methods
        const loadingContainer = document.getElementById('loading-container');
        if (loadingContainer) {
          console.log('App.tsx: Forcefully hiding loading screen');
          
          // Multi-layered approach to ensure it's hidden
          loadingContainer.style.visibility = 'hidden';
          loadingContainer.style.opacity = '0';
          loadingContainer.style.display = 'none';
          loadingContainer.style.pointerEvents = 'none';
          loadingContainer.style.zIndex = '-9999';
          
          // Force browser to repaint by accessing offsetHeight
          loadingContainer.offsetHeight;
          
          // Mark as hidden
          window.__LOADING_SCREEN_HIDDEN = true;
          console.log('App.tsx: Loading screen forcefully hidden');
        }
      } catch (e) {
        console.error('Failed to forcefully hide loading screen:', e);
      }
    }
  
    // Apply MULTIPLE independent attempts to hide the loading screen
    if (typeof window !== 'undefined') {
      // First attempt - immediate
      hideScreenAggressively();
      
      // Second attempt - after short delay
      setTimeout(hideScreenAggressively, 300);
      
      // Third attempt - use the window function if available
      setTimeout(() => {
        if (typeof window.hideLoadingScreen === 'function') {
          try {
            window.hideLoadingScreen();
          } catch (e) {
            console.error('Error using window.hideLoadingScreen:', e);
          }
        }
        
        // Cleanup timeout
        if (typeof window.clearStartupTimeout === 'function') {
          window.clearStartupTimeout();
          console.log('App is fully loaded, clearing startup timeout');
        }
      }, 600);
      
      // Fourth attempt - extra insurance
      setTimeout(hideScreenAggressively, 1000);
    }
  }, []);
  
  const [startupTime] = useState(() => {
    // Record startup metrics if available
    const metrics = window.__PEERPA_LOAD_METRICS;
    if (metrics) {
      console.log("App startup metrics:", {
        appImport: metrics.appImport ? Math.round(metrics.appImport) + "ms" : "N/A",
        appRender: metrics.appRender ? Math.round(metrics.appRender) + "ms" : "N/A", 
        totalStartupTime: metrics.fullAppLoaded ? Math.round(metrics.fullAppLoaded) + "ms" : "N/A"
      });
    }
    return Date.now();
  });
  
  console.log("Main component rendering at:", new Date().toISOString());
  console.log("Current location:", location);

  // Get auth context to update it directly
  const { setUser } = useAuth();

  // Clear the startup timeout when component mounts - this indicates successful app initialization
  // Initialize offline support and service worker
  useEffect(() => {
    // Clear startup timeout to prevent error display
    if (window.clearStartupTimeout) {
      window.clearStartupTimeout();
      console.log('App successfully initialized - startup timeout cleared');
    }
    
    // Initialize offline support
    try {
      console.log('Initializing offline support and service worker');
      initOfflineSupport();
      
      // Update last online time if connected
      if (navigator.onLine) {
        updateLastOnlineTime();
      }
      
      // Set up event listeners for connection status
      window.addEventListener('online', () => {
        console.log('Connection restored - syncing data');
        updateLastOnlineTime();
        // Display reconnection toast
        try {
          // Use the toast-helper utility
          import('./lib/toast-helper').then(({ showToast }) => {
            showToast({
              title: 'Connection Restored',
              description: 'You are back online. Syncing your data...',
              variant: 'default'
            });
          }).catch(err => {
            console.error('Failed to show toast:', err);
          });
        } catch (error) {
          console.warn('Toast notification not available:', error);
        }
      });
      
      window.addEventListener('offline', () => {
        console.log('Connection lost - switching to offline mode');
        // Display offline toast
        try {
          // Use the toast-helper utility consistently
          import('./lib/toast-helper').then(({ showToast }) => {
            showToast({
              title: 'Offline Mode',
              description: 'You are now offline. Limited functionality available.',
              variant: 'destructive'
            });
          }).catch(err => {
            console.error('Failed to show toast:', err);
          });
        } catch (error) {
          console.warn('Toast notification not available:', error);
        }
      });
    } catch (error) {
      console.error('Failed to initialize offline support:', error);
    }
  }, []);

  // Fetch current user data for auth status - optimized to prevent excessive calls
  useEffect(() => {
    // Store last auth check timestamp to prevent excessive calls
    const lastAuthCheck = sessionStorage.getItem('lastAuthCheck');
    const now = Date.now();
    
    // Prevent multiple auth checks within a short time period (3 seconds)
    // but always run on first load
    if (lastAuthCheck && now - parseInt(lastAuthCheck, 10) < 3000) {
      console.log("App: Skipping redundant auth check");
      return;
    }
    
    // Record this auth check
    sessionStorage.setItem('lastAuthCheck', now.toString());
    
    // Use immediate loading instead of staggered loading for faster startup
    console.log("App: Fetching current user from API...");

    // Check if we already have user data in localStorage
    const storedUser = localStorage.getItem('authUser');
    const sessionAuth = sessionStorage.getItem('sessionAuthenticated');
    
    // If we have stored user data and valid session, use it immediately
    if (storedUser && sessionAuth === 'true') {
      try {
        const userData = JSON.parse(storedUser);
        // Only set user from cache if it's properly formed
        if (userData && userData.id) {
          console.log("App: Using cached user data:", userData.username);
          setUser(userData);
        }
      } catch (e) {
        console.error("App: Error parsing stored user data:", e);
        // Clear invalid data
        localStorage.removeItem('authUser');
      }
    }
    
    // Immediately verify with server instead of delaying
    const timer = setTimeout(() => {
      // Use the API function from our lib/api.ts to get current user
      import('./lib/api').then(({ getCurrentUser }) => {
        getCurrentUser()
          .then(userData => {
            if (userData) {
              console.log("App: Current user data from API:", userData.username);
              localStorage.setItem('authUser', JSON.stringify(userData));
              sessionStorage.setItem('sessionAuthenticated', 'true');
              
              // Update the auth context directly
              setUser(userData);
            }
          })
          .catch(error => {
            console.error("App: Error fetching current user:", error);
          });
      })
      .catch(error => {
        console.error("App: Error importing API functions:", error);
      });
    }, 0); // Run immediately, without any delay
    
    return () => clearTimeout(timer);
  }, [setUser]);
  
  // Hide floating buttons when on chat page or when triggered by a component
  useEffect(() => {
    // Always check URL first
    if (location === '/chat') {
      setFloatingButtonsVisible(false);
    } else if (location === '/help') {
      // Don't set to true for Help page - the Help component will manage visibility
      // based on whether the chat is open or not
      console.log("On help page - component will manage floating buttons visibility");
    } else {
      // For all other pages, show the floating buttons by default
      setFloatingButtonsVisible(true);
    }
  }, [location]);
  
  // Listen for global events to control floating buttons visibility
  useEffect(() => {
    const handleShowChat = () => {
      console.log("Global event: hidingFloatingButtons received");
      setFloatingButtonsVisible(false);
    };
    
    const handleHideChat = () => {
      console.log("Global event: showingFloatingButtons received");
      setFloatingButtonsVisible(true);
    };
    
    // Register global event listeners
    document.addEventListener('hidingFloatingButtons', handleShowChat);
    document.addEventListener('showingFloatingButtons', handleHideChat);
    
    return () => {
      // Clean up event listeners
      document.removeEventListener('hidingFloatingButtons', handleShowChat);
      document.removeEventListener('showingFloatingButtons', handleHideChat);
    };
  }, []);
  
  // Initialize iOS 18 detection and apply patches if needed
  useEffect(() => {
    try {
      // Import the functions dynamically to prevent undefined errors
      import('@/lib/ios18Detector').then(module => {
        // Run iOS 18 detection using our utility functions
        const isIOSDevice = module.isIOS();
        const isIOS18Device = module.isIOS18();
        const isIOS1831Device = module.isIOS1831();
        
        console.log("iOS detection: isIOS:", isIOSDevice, "isIOS18:", isIOS18Device, "isIOS1831:", isIOS1831Device);
        
        if (isIOS18Device) {
          console.log("iOS 18 detected, applying session tracking enhancements");
          module.applyIOS18Fixes();
          
          // Set global flag for iOS 18 detection
          (window as any).__IOS_18_DETECTED = true;
          
          // For iOS 18.3.1, set more specific flag
          if (isIOS1831Device) {
            console.log("iOS 18.3.1 specifically detected - applying specialized session handling");
            (window as any).__IOS_18_3_1_DETECTED = true;
            
            // Force the fallback mode by setting a flag that the connection handlers will check
            (window as any).__FORCE_FALLBACK_MODE = true;
          }
        }
      }).catch(error => {
        console.error("Failed to import iOS 18 detector:", error);
      });
    } catch (error) {
      console.error("Error in iOS 18 detection:", error);
    }
  }, []);
  
  // Add mobile-specific behavior once mobile context is ready
  useEffect(() => {
    if (isMobileReady) {
      console.log("Mobile context is ready, device is", isMobile ? "mobile" : "desktop");
      
      if (isMobile) {
        // Apply mobile-specific behaviors
        console.log("Applying mobile-specific behaviors in App component");
        
        // Add classes to help with styling
        document.documentElement.classList.add('app-mobile-ready');
        
        // For Android devices, verify fixes were applied and set flag
        if (isAndroid) {
          try {
            // EMERGENCY FIX: Always apply Android fixes when loaded
            // without triggering a reload loop
            if (!document.documentElement.classList.contains('android-fixes-applied')) {
              console.log('Adding Android optimizations directly');
              document.documentElement.classList.add('android-fixes-applied');
              
              // Apply hardware acceleration
              document.documentElement.style.setProperty('will-change', 'transform');
              document.documentElement.style.setProperty('backface-visibility', 'hidden');
              
              // Store that we've applied fixes
              localStorage.setItem('peerpa.androidFixesApplied', Date.now().toString());
            }
            
            // Add Android-specific class if not already present
            if (!document.documentElement.classList.contains('android-device')) {
              document.documentElement.classList.add('android-device');
            }
          } catch (e) {
            console.error('Error checking Android fixes:', e);
          }
        }
        
        // Log device info for debugging
        console.log("Mobile device info:", { 
          isIOS, 
          isAndroid,
          userAgent: navigator.userAgent,
          viewportWidth: window.innerWidth,
          viewportHeight: window.innerHeight,
          androidFixesApplied: localStorage.getItem('peerpa.androidFixesApplied') ? 'yes' : 'no'
        });
      }
    }
  }, [isMobile, isIOS, isAndroid, isMobileReady]);
  
  // Get user data from context
  const { user } = useAuth();
  
  // Clear the startup timeout when app is successfully loaded
  useEffect(() => {
    if (isMobileReady) {
      // App is ready and mobile context is available
      // We'll clear the timeout even without user to avoid hanging
      if (window.clearStartupTimeout) {
        console.log("App is fully loaded, clearing startup timeout");
        window.clearStartupTimeout();
      } else {
        console.log("Warning: clearStartupTimeout function not available");
      }
      
      // Show success message for troubleshooting
      if (isAndroid) {
        console.log(`Android device successfully loaded the application! ${Date.now()}`);
      }
      
      // Update loading screen
      const loadingElement = document.getElementById('application-loading');
      if (loadingElement) {
        console.log("Hiding loading screen");
        loadingElement.classList.add('completed');
        // Remove loading element after fade out completes
        setTimeout(() => {
          loadingElement.style.display = 'none';
        }, 500);
      }
    }
  }, [isMobileReady, isAndroid]);

  // Define all routes in an array for easier management
  const routes = [
    // Protected routes
    { path: "/", component: Dashboard },
    { path: "/dashboard", component: Dashboard },
    { path: "/referrals", component: Referrals },
    { path: "/matrix", component: ReferralMatrixPage },
    { path: "/games", component: Games },
    { path: "/games/:gameId", component: Games },
    { path: "/multiplayer", component: Multiplayer },
    { path: "/daily-challenges", component: DailyChallenges },
    { path: "/transactions", component: Transactions },
    { path: "/profile", component: Profile },
    { path: "/help", component: Help },
    { path: "/help/accessibility", component: AccessibilityHelp },
    { path: "/subscription", component: Subscription },
    { path: "/subscription/complete", component: SubscriptionComplete },
    { path: "/subscription/manage", component: SubscriptionManagement },
    { path: "/subscription-management", component: SubscriptionManagement },
    { path: "/subscribe", component: Subscribe },
    { path: "/checkout", component: Checkout },
    { path: "/checkout-success", component: CheckoutSuccess },
    { path: "/subscription/manage/features", component: FeaturesManagement },
    { path: "/subscription/manage/payment", component: PaymentManagement },
    { path: "/subscription/manage/cancel", component: SubscriptionCancel },
    { path: "/financial-tools", component: FinancialTools },
    { path: "/payments", component: PaymentManagement },
    { path: "/payment", component: Payment },
    { path: "/payment-success", component: PaymentSuccess },
    { path: "/guides", component: Guides },
    { path: "/surveys", component: Surveys },
    { path: "/network-status", component: NetworkStatus },
    { path: "/admin", component: Admin },
    { path: "/language-settings", component: LanguageSettings },
    { path: "/profile/language", component: LanguageSettings },
    { path: "/support-tickets", component: SupportTickets },
    { path: "/notifications/test", component: NotificationTest },
    { path: "/help/security-report", component: SecurityReport },
    { path: "/settings/cache", component: CacheSettings },
    { path: "/security-center", component: Security },
    { path: "/crypto-wallet", component: CryptoWallet },
    { path: "/sound-test", component: SoundTestPage, public: true },
    { path: "/sound-test-new", component: SoundTest, public: true },
    { path: "/license", component: LicenseVerification, public: true },
    { path: "/ip-rights", component: IPRights, public: true },
    { path: "/team", component: TeamLicense, public: true },
    { path: "/team-subscription", component: TeamSubscriptionPage },
    { path: "/waitlist", component: Waitlist },
    
    // Public pages (no auth required)
    { path: "/auth", component: Auth, public: true }, // Consolidated Auth page with both login and registration
    
    // Redirect old auth routes to new consolidated Auth page
    { path: "/login", component: () => <Redirect to="/auth" />, public: true },
    { path: "/register", component: () => <Redirect to="/auth" />, public: true },
    { path: "/mobile-login", component: MobileLoginPage, public: true }, // Mobile-optimized login page for iOS
    { path: "/chat", component: Chat, public: true },
    { path: "/terms", component: Terms, public: true },
    { path: "/privacy", component: Privacy, public: true },
    { path: "/cookies", component: Cookies, public: true },
    { path: "/security", component: Security, public: true },
    { path: "/accessibility", component: Accessibility, public: true },
    { path: "/about", component: AboutUs, public: true },
    { path: "/our-mission", component: OurMission, public: true },
    { path: "/careers", component: Careers, public: true },
    { path: "/careers/apply", component: CareersApply, public: true },
    { path: "/press", component: Press, public: true },
    { path: "/blog", component: Blog, public: true },
    { path: "/contact", component: Contact, public: true },
    { path: "/api-docs", component: ApiDocs, public: true },
    { path: "/community", component: Community, public: true },
    { path: "/community/discussions", component: Community, public: true },
    { path: "/community/forum/:id", component: Community, public: true },
    { path: "/community/topic/:id", component: Community, public: true },
    { path: "/community/all-forums", component: Community, public: true },
    { path: "/community/success-stories", component: Community, public: true },
    { path: "/community/success-story/:id", component: Community, public: true },
    { path: "/community/all-events", component: Community, public: true },
    { path: "/community/member/:id", component: Community, public: true },
    { path: "/community/members", component: Community, public: true },
    { path: "/community/resource/:id", component: Community, public: true },
    { path: "/community/resources", component: Community, public: true },
    { path: "/community/event/:id", component: Community, public: true },
    { path: "/partners", component: Partners, public: true },
    { path: "/partnerships", component: Partnerships, public: true },
    { path: "/partner", component: PartnerApplication, public: true },
    { path: "/partner-application", component: PartnerApplication, public: true },
    { path: "/ux-enhancements", component: UXEnhancements, public: true },
  ];

  // Function to handle ErrorBoundary resets
  const handleErrorReset = () => {
    console.log("Error boundary reset triggered");
    // Manual error recovery (simplified)
    try {
      // Clear any error caches that might be in localStorage
      const errorKeys = Object.keys(localStorage).filter(k => k.startsWith('error_'));
      errorKeys.forEach(key => localStorage.removeItem(key));
      
      // Refresh critical app state
      console.log("Performing app state recovery");
      
      // Force re-authentication if needed
      const authUser = localStorage.getItem('authUser');
      if (authUser) {
        try {
          // Try to parse and validate stored user data
          const userData = JSON.parse(authUser);
          if (!userData || !userData.id) {
            console.log("Invalid stored user data, removing");
            localStorage.removeItem('authUser');
            sessionStorage.removeItem('sessionAuthenticated');
          }
        } catch (e) {
          console.log("Corrupted auth data, removing", e);
          localStorage.removeItem('authUser');
          sessionStorage.removeItem('sessionAuthenticated');
        }
      }
    } catch (error) {
      console.error("Recovery failed:", error);
    }
  };

  return (
    <IOSRedirect>
      <TooltipProvider>
        <UIOverlayContext.Provider value={{ 
          isMenuOpen, 
          setIsMenuOpen, 
          floatingButtonsVisible, 
          setFloatingButtonsVisible 
        }}>
          <CountdownProvider>
            {/* Performance optimizers for faster startup */}
            <StartupOptimizer />
            <PreloadResources />
            
            {/* Initialize toast system for global error handling */}
            <ToastInitializer />
            
            {/* Initialize sound system */}
            <SoundInitializer />
            
            {/* Wrap the entire application in an ErrorBoundary for self-healing */}
            <Suspense fallback={<FullPageLoader label="Loading application..." />}>
            <AppErrorBoundary onReset={handleErrorReset}>
              {/* Enhanced motion background with more visible animation */}
              <div id="background-container" className="fixed inset-0 z-[-1] overflow-hidden pointer-events-none">
                <div id="animated-bg" className="absolute inset-0 opacity-15 bg-gradient-to-br from-primary/30 to-accent/30 animate-gradient"></div>
                <div id="bg-radial" className="absolute inset-0 bg-gradient-radial from-primary/10 to-transparent"></div>
              </div>
              
              {/* Lazy load the EnhancedMotionBackground for better performance */}
              <Suspense fallback={null}>
                {!isMobile && <EnhancedMotionBackground intensity="medium" primaryColor="#3b82f6" secondaryColor="#9333ea" particleCount={80} speed={1.2} />}
              </Suspense>
              
              {/* Weather Effects */}
              <Suspense fallback={null}>
                <WeatherEffects />
              </Suspense>
              
              {/* UI components removed temporarily for stability */}
              
              <div className="App relative">
                {/* Routes with consistent loading screens */}
                <Switch>
                  {/* Root path redirect to Auth page for unauthenticated users */}
                  <Route
                    path="/"
                    component={() => {
                      if (!user) {
                        return <Redirect to="/auth" />;
                      } else {
                        return (
                          <Suspense fallback={<FullPageLoader label="Loading dashboard..." />}>
                            <Dashboard />
                          </Suspense>
                        );
                      }
                    }}
                  />
                  
                  {/* Map all other defined routes */}
                  {routes.map(({ path, component: Component, public: isPublic }) => {
                    if (isPublic) {
                      return (
                        <Route
                          key={path}
                          path={path}
                          component={() => (
                            <Suspense fallback={<FullPageLoader label="Loading page..." />}>
                              <Component />
                            </Suspense>
                          )}
                        />
                      );
                    } else {
                      return (
                        <ProtectedRoute
                          key={path} 
                          path={path}
                          component={() => (
                            <Suspense fallback={<FullPageLoader label="Loading content..." />}>
                              <Component />
                            </Suspense>
                          )}
                        />
                      );
                    }
                  })}
                  
                  {/* Handle 404 not found */}
                  <Route component={NotFound} />
                </Switch>
              </div>
            </AppErrorBoundary>
          </Suspense>
          </CountdownProvider>
        </UIOverlayContext.Provider>
      </TooltipProvider>
    </IOSRedirect>
  );
}

export default App;